import { ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { OverlayComponent } from './overlay.component';
var OverlayService = (function () {
    function OverlayService(rebirthUIConfig, componentFactoryResolver, injector) {
        this.rebirthUIConfig = rebirthUIConfig;
        this.componentFactoryResolver = componentFactoryResolver;
        this.injector = injector;
        this.overlayCount = 0;
    }
    OverlayService.prototype.open = function (options) {
        if (!this.overlayCount++) {
            this.createOverlay(options);
        }
    };
    OverlayService.prototype.createOverlay = function (options) {
        var rootContainer = options.rootContainer || this.rebirthUIConfig.rootContainer;
        if (!rootContainer) {
            throw new Error('Should setup ViewContainerRef on modal overlay or rebirth config service!');
        }
        var componentFactory = this.componentFactoryResolver.resolveComponentFactory(OverlayComponent);
        var injector = options.injector || this.injector;
        this.overlayRef = rootContainer.createComponent(componentFactory, rootContainer.length, injector);
        var cmp = this.overlayRef.instance;
        cmp.addContent(options);
    };
    OverlayService.prototype.close = function () {
        this.overlayCount--;
        if (this.overlayCount < 1 && this.overlayRef) {
            this.overlayRef.destroy();
        }
    };
    return OverlayService;
}());
export { OverlayService };
OverlayService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
OverlayService.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: ComponentFactoryResolver, },
    { type: Injector, },
]; };
//# sourceMappingURL=overlay.service.js.map